#ifndef __NVC0_MACROS_H__
#define __NVC0_MACROS_H__

/**
 * The list of macros defined in the 3d object
 */

#define NVC0_3D_MACRO_VERTEX_ARRAY_PER_INSTANCE			0x00003800

#define NVC0_3D_MACRO_VERTEX_ARRAY_SELECT			0x00003808

#define NVC0_3D_MACRO_BLEND_ENABLES				0x00003810

#define NVC0_3D_MACRO_POLYGON_MODE_FRONT			0x00003818
#define NVC0_3D_MACRO_POLYGON_MODE_FRONT_POINT			0x00001b00
#define NVC0_3D_MACRO_POLYGON_MODE_FRONT_LINE			0x00001b01
#define NVC0_3D_MACRO_POLYGON_MODE_FRONT_FILL			0x00001b02

#define NVC0_3D_MACRO_POLYGON_MODE_BACK				0x00003820
#define NVC0_3D_MACRO_POLYGON_MODE_BACK_POINT			0x00001b00
#define NVC0_3D_MACRO_POLYGON_MODE_BACK_LINE			0x00001b01
#define NVC0_3D_MACRO_POLYGON_MODE_BACK_FILL			0x00001b02

#define NVC0_3D_MACRO_GP_SELECT					0x00003828

#define NVC0_3D_MACRO_TEP_SELECT				0x00003830

#define NVC0_3D_MACRO_DRAW_ARRAYS_INDIRECT			0x00003838

#define NVC0_3D_MACRO_DRAW_ELEMENTS_INDIRECT			0x00003840

#define NVC0_3D_MACRO_DRAW_ARRAYS_INDIRECT_COUNT		0x00003848

#define NVC0_3D_MACRO_DRAW_ELEMENTS_INDIRECT_COUNT		0x00003850

#define NVC0_3D_MACRO_QUERY_BUFFER_WRITE			0x00003858

#define NVC0_CP_MACRO_LAUNCH_GRID_INDIRECT       0x00003860

#endif /* __NVC0_MACROS_H__ */
